#!/bin/bash

CONF_FILE=/etc/squid/squid.conf
if [ ! -f $CONF_FILE ]; then
    # silently exit if no configuration file
    exit 0
fi
CACHE_LOG="`awk '$1 == "cache_log" {x=$2} END{print x}' $CONF_FILE`"
if [ -z "$CACHE_LOG" ]; then
    # silently exit if no cache_log setting in the configuration file
    # squid won't start without it
    exit 0
fi
CACHE_DIR="`dirname $CACHE_LOG`"
case "`basename $CACHE_DIR`" in
    *\$*) CACHE_DIR="`dirname $CACHE_DIR`" ;; # remove macro sub-part
esac
LOGFILE="$CACHE_DIR/squidcron.log"

if [ ! -f $LOGFILE.old ]; then
    touch $LOGFILE.old
elif [ -n "`find $LOGFILE.old -mtime +7 2>/dev/null`" ]; then
    rm -f $LOGFILE.old
    mv $LOGFILE $LOGFILE.old
fi

# Read SQUID_ variable settings from one of these files.
# Note that they need to be preceded by "export" to be usable.
if [ -f /etc/sysconfig/frontier-squid ]; then
    eval `grep "SQUID_" /etc/sysconfig/frontier-squid`
elif [ -f /etc/sysconfig/frontier-squid.sh ]; then
    eval `grep "SQUID_" /etc/sysconfig/frontier-squid.sh`
fi

date >> $LOGFILE
/usr/sbin/fn-local-squid.sh rotate >> $LOGFILE 2>&1
